# Changelog

<!--next-version-placeholder-->

## v0.5.1 (2023-07-17)
### Documentation
* **readme:** More informative ([`1c64ef6`](https://github.com/robinvandernoord/su6-plugin-svelte-check/commit/1c64ef6e75c26e3fe6f985b673444a158f0ee1d1))

## v0.5.0 (2023-07-17)
### Feature
* Allow defining custom target ([`bcac570`](https://github.com/robinvandernoord/su6-plugin-svelte-check/commit/bcac57077b53d7c1b8a79d2100309b3448739fc3))

## v0.4.0 (2023-07-17)
### Feature
* Add install-svelte-check command ([`84630d2`](https://github.com/robinvandernoord/su6-plugin-svelte-check/commit/84630d254fd1946d5789f50a427d29024f41b227))

## v0.3.0 (2023-07-17)
### Feature
* Allow specifying a custom --node-modules directory which should have `svelte-check` ([`db1dc42`](https://github.com/robinvandernoord/su6-plugin-svelte-check/commit/db1dc42720e7f94020249b6859097b3cb541cda0))

## v0.2.2 (2023-07-17)
### Fix
* Don't include node modules in git!! ([`360325c`](https://github.com/robinvandernoord/su6-plugin-svelte-check/commit/360325c02ed99fb34519941061e9b78679601d61))

## v0.2.1 (2023-07-17)

### Fix

* Require the latest version of su6 ([`6300e97`](https://github.com/robinvandernoord/su6-plugin-svelte-check/commit/6300e974e732b9b5089490665c80b0d54d0071e9))

## v0.2.0 (2023-07-17)

### Feature

* Add svelte-check to `su6 all` ([`b54e102`](https://github.com/robinvandernoord/su6-plugin-svelte-check/commit/b54e102cdfcbc4e8e1ec9f134cc9c559464ee1f7))

## v0.1.0 (2023-07-15)
### Feature
* Initial version of plugin ([`7a171b8`](https://github.com/robinvandernoord/su6-plugin-svelte-check/commit/7a171b8327653ab366e13388471c342ab1c38873))

## v0.1.0 (2023-06-05)
### Feature

* Initial version of the demo plugin ([`dc02818`](https://github.com/robinvandernoord/su6-plugin-demo/commit/dc02818b5d361469fa0ca480eee7394628faad89))
